==> ingdao-0.0.13.tar.gz: example/counter/lib/datalayer/entity/update_details_req_web.dart <==
import 'package:ingdao/dataflow/control/dfquery.dart';
import 'package:ingdao/dataflow/entity/dfbaseentity.dart';
import 'package:ingdao/dataflow/entity/dfwebentity.dart';
import 'package:ingdao/dataflow/field/dfbasefield.dart';
import 'package:ingdao/dataflow/field/dfwebfield.dart';
import '../field/update_details_req_field.dart';
import 'response_web.dart';
import 'updatedetailsweb.dart';
import 'package:ingdao/dataflow/field/dffieldtype.dart';
import 'package:object_mapper/object_mapper.dart';
import '../../app_control.dart';

class UpdateDetailsReqWeb extends DfWebEntity with UpdateDetailsReqField {

  String appName;
  int platform;
  String version;

  UpdateDetailsReqWeb ({String pAppName, int pPlatform, String pVersion}) : super(contextPath: AppControl.endPoint) {
    fAppName = DfWebField(entity: this, name: "appName", fieldType: DfFieldType.text(), getObjectValue: () => appName, setObjectValue: (v) => appName = v, value: pAppName);
    fPlatform = DfWebField(entity: this, name: "platform", fieldType: DfFieldType.integer(), getObjectValue: () => platform, setObjectValue: (v) => platform = v, value: pPlatform);
    fVersion = DfWebField(entity: this, name: "version", fieldType: DfFieldType.text(), getObjectValue: () => version, setObjectValue: (v) => version = v, value: pVersion);
  }

  //Define what are the fields will map back the result from http response Map<String,dynamic>
  @override
  List<DfWebField> fields() {
     return [fAppName,
            fPlatform,
            fVersion];
  }

  @override
  DfWebReqParam convertToWebReqParam(DfQuery query) {
    DfWebReqParam param = DfWebReqParam();
    if (AppControl.accessToken != null)
      param.setAuthToken(AppControl.accessToken);

    if (query.purpose == DfQueryPurpose.ADD) {
      final dict = query.extraReq.toDict();
      param.reqBody = dict;

      return param;
    }
    return null;
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return UpdateDetailsReqWeb();
  }

  @override
  DfBaseEntity<DfWebField> jsonToObject(DfQueryPurpose purpose, Mapper map) {
    if (purpose == DfQueryPurpose.ADD)
      return map.toObject<ResponseWeb>();

    return null;
  }

  @override
  void customFieldJsonMap(Mapper map, List<DfWebField> fields) {
    // TODO: implement customFieldJsonMap
  }
}

==> ingdao-0.0.19.tar.gz: example/counter/lib/datalayer/entity/update_details_req_web.dart <==
import 'package:ingdao/dataflow/control/dfquery.dart';
import 'package:ingdao/dataflow/entity/dfbaseentity.dart';
import 'package:ingdao/dataflow/entity/dfwebentity.dart';
import 'package:ingdao/dataflow/field/dfbasefield.dart';
import 'package:ingdao/dataflow/field/dfwebfield.dart';
import '../field/update_details_req_field.dart';
import 'response_web.dart';
import 'updatedetailsweb.dart';
import 'package:ingdao/dataflow/field/dffieldtype.dart';
import 'package:object_mapper/object_mapper.dart';
import '../../app_control.dart';

class UpdateDetailsReqWeb extends DfWebEntity with UpdateDetailsReqField {

  String appName;
  int platform;
  String version;

  UpdateDetailsReqWeb ({String pAppName, int pPlatform, String pVersion}) : super(contextPath: AppControl.endPoint) {
    fAppName = DfWebField(entity: this, name: "appName", fieldType: DfFieldType.text(), getObjectValue: () => appName, setObjectValue: (v) => appName = v, value: pAppName);
    fPlatform = DfWebField(entity: this, name: "platform", fieldType: DfFieldType.integer(), getObjectValue: () => platform, setObjectValue: (v) => platform = v, value: pPlatform);
    fVersion = DfWebField(entity: this, name: "version", fieldType: DfFieldType.text(), getObjectValue: () => version, setObjectValue: (v) => version = v, value: pVersion);
  }

  //Define what are the fields will map back the result from http response Map<String,dynamic>
  @override
  List<DfWebField> fields() {
     return [fAppName,
            fPlatform,
            fVersion];
  }

  @override
  DfWebReqParam convertToWebReqParam(DfQuery query) {
    DfWebReqParam param = DfWebReqParam();
    if (AppControl.accessToken != null)
      param.setAuthToken(AppControl.accessToken);

    if (query.purpose == DfQueryPurpose.ADD) {
      final dict = query.extraReq.toDict();
      param.reqBody = dict;

      return param;
    }
    return null;
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return UpdateDetailsReqWeb();
  }

  @override
  DfBaseEntity<DfWebField> parseExecRawJsonResultToEntity(DfQueryPurpose purpose, Mapper map) {
    if (purpose == DfQueryPurpose.ADD) {
      ResponseWeb.dataType = UpdateDetailsWeb().runtimeType;
      return map.toObject<ResponseWeb>();
    }

    return null;
  }

  @override
  void customFieldJsonMap(Mapper map, List<DfWebField> fields) {
    // TODO: implement customFieldJsonMap
  }
}
